<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://byronj.me
 * @since      1.0.0
 *
 * @package    Editor_Appearance_Access
 * @subpackage Editor_Appearance_Access/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Editor_Appearance_Access
 * @subpackage Editor_Appearance_Access/admin
 * @author     Byron Johnson <me@byronj.me>
 */
class Editor_Appearance_Access_Admin_Display {

    private $beaa_options;

    /**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.1.0
	 */
	public function __construct() {
        $this->beaa_options = get_option('beaa_settings');
    }

    public function eaa_console_log($output, $with_script_tags = true){
        $js_code = 'console.log(' . json_encode($output, JSON_HEX_TAG) . ');';

        if ($with_script_tags) {
            $js_code = '<script>' . $js_code . '</script>';
        }

        echo $js_code;
    }

    public function remove_caps(){
        $editor = get_role('editor');
        $editor->remove_cap('install_themes');
        $editor->remove_cap('update_themes');
        $editor->remove_cap('delete_themes');
        $editor->remove_cap('switch_themes');
    }



    public function build_form(){
        global $submenu;
        $appearance_items = $submenu['themes.php'];
        

        ?>
            <form method="post" action="options.php">
                <?php 
                    // Load form settings
                    settings_fields('beaa_settings_group'); 
                ?>
                
                <div class="wrap">	
                    <h2> <?php  _e('Editor Appearance Access Options') ?></h2>
                    
                    <div class="eaa-description">
                        Select the menus that will be available to all Editors.
                    </div>

                    <div class="eaa-checkboxes">
                        <?php
                            foreach($appearance_items as $a_item){

                                if( $a_item[2] != 'custom-header' ) {
                                    $item_name = $a_item[0];
                                    $item_lowercase = strtolower($item_name);

                                    if(isset($this->beaa_options[$item_lowercase]) ){
                                        $current_option = $this->beaa_options[$item_lowercase];
                                    } else {
                                        $current_option = 0;
                                    }
                                
                                    
                                    // If no post type is selected, set input value to 0
                                    $html = '<div class="eaa-checkbox">';
                                    $html .= '<input id="' . $item_lowercase . '" type="checkbox" value="1" name="beaa_settings[' . $item_lowercase . ']"'. checked($current_option, '1' , false ) .'/>';
                                    $html .= '<label class="description" for="beaa_settings[' . $item_lowercase . ']">' . $a_item[0] . '</label>';
                                    $html .= '</div>';
                                    echo $html;
                                }
                            }
                        ?>
                    </div>

                    <p class="submit">
                        <input type="submit" class="button-primary" value="<?php _e('Save Options', 'beaa_domain');  ?> "/>
                    </p>
                </form>
        </div>
        <?php 
    }

    public function add_remove_menu_pages(){

        $user = wp_get_current_user();
    
        $checked_roles = array('editor');
        global $submenu;


        // Remove Appearance menu option if no options are selected
        if(empty($this->beaa_options) && array_intersect($checked_roles, $user->roles ) ){
            remove_menu_page('themes.php');
        }

        if( !empty($this->beaa_options) && array_intersect($checked_roles, $user->roles ) ) {
            foreach ($submenu['themes.php'] as $key => $value){
                $lowercase_value = strtolower($value[0]);
                

                if( !isset($this->beaa_options[$lowercase_value]) ){
                    unset($submenu['themes.php'][$key]);
                }
            }

            
        }

        if( array_key_exists('theme editor', $this->beaa_options)){
            $editor = get_role('editor');
            $editor->add_cap('edit_themes');
        } else {
            $editor = get_role('editor');
            $editor->remove_cap('edit_themes');
        }

        if( array_key_exists('themes', $this->beaa_options)){
            $editor = get_role('editor');
            $editor->add_cap('install_themes');
            $editor->add_cap('update_themes');
            $editor->add_cap('delete_themes');
            $editor->add_cap('switch_themes');
            
        } else {
            $editor = get_role('editor');
            $editor->remove_cap('install_themes');
            $editor->remove_cap('update_themes');
            $editor->remove_cap('delete_themes');
            $editor->remove_cap('switch_themes');
        }
        
    }
    

	 // create options page under settings menu
     public function add_options_link() {
		add_options_page('Editor Appearance Access Options', 'Editor Appearance Access', 'manage_options', 'beaa-options', [$this, 'build_form'] );
    }
    

	// register options page under settings menu
	public function register_settings(){
		register_setting('beaa_settings_group', 'beaa_settings');
    }
    
    /**
	 * Add menu and settings
	 *
	 * @since    1.1.0
	 */
    public function render_results() {
        add_action('admin_menu',  [ $this, 'add_options_link' ]);
        add_action('admin_init',  [ $this, 'register_settings']);
        add_action('admin_menu', [$this, 'add_remove_menu_pages']);        
    }

}

// content shown on settings page 
$public_display = new Editor_Appearance_Access_Admin_Display();
$public_display->render_results();