<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://byronj.me
 * @since             1.0.0
 * @package           Editor_Appearance_Access
 *
 * @wordpress-plugin
 * Plugin Name:       Editor Appearance Access
 * Description:       Grants the Editor user role access to selected menus under the Appearance menu.
 * Version:           1.0.0
 * Author:            Byron Johnson
 * Author URI:        https://byronj.me
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       editor-appearance-access
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'EDITOR_APPEARANCE_ACCESS_VERSION', '1.0.0' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-editor-appearance-access-activator.php
 */
function activate_editor_appearance_access() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-editor-appearance-access-activator.php';
	Editor_Appearance_Access_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-editor-appearance-access-deactivator.php
 */
function deactivate_editor_appearance_access() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-editor-appearance-access-deactivator.php';
	Editor_Appearance_Access_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_editor_appearance_access' );
register_deactivation_hook( __FILE__, 'deactivate_editor_appearance_access' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-editor-appearance-access.php';

/**
 * Adds settings link to plugin dashboard
 */
add_filter('plugin_action_links_'.plugin_basename(__FILE__), 'eaa_add_plugin_page_settings_link');

function eaa_add_plugin_page_settings_link( $links ) {
	$links[] = '<a href="' .
		admin_url( 'options-general.php?page=beaa-options' ) .
		'">' . __('Settings') . '</a>';
	return $links;
}


/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_editor_appearance_access() {

	$plugin = new Editor_Appearance_Access();
	$plugin->run();

}
run_editor_appearance_access();
